@@ -141,6 +141,10 @@ class SkillFocusPriority:
     default_level: int
     specific_levels: Dict[Union[SpecificApplicationFocus, ApplicationFocus], int] = field(default_factory=lambda: {})
 
+    @property
+    def levels(self) -> Dict[Union[SpecificApplicationFocus, ApplicationFocus], int]:
+        return {focus: self.get_level(focus) for focus in [*SpecificApplicationFocus, *ApplicationFocus]}
+
     def get_level(self, focus: Optional[Union[SpecificApplicationFocus, ApplicationFocus]] = None):
         if focus is None:
             return self.default_level
