@@ -6,7 +6,7 @@ import pyexlatex.resume as lr
 
 from derobertis_cv.models.organization import Organization, OrganizationCharacteristics
 from derobertis_cv.pldata.cover_letters.models import ApplicationTarget, HiringManager, Gender
-from derobertis_cv.pldata.cv import CVModel
+from derobertis_cv.pldata.cv import CVModel, ResumeSection
 from derobertis_cv.pldata.employment_model import JobIDs
 
 DC_KWARGS = dict(
@@ -647,6 +647,93 @@ BEA = Organization(
 )
 BEA_HM = HiringManager('NARG Search Committee', is_person=False)
 BEA_TARGET = ApplicationTarget(BEA, 'Research Economist', person=BEA_HM)
+BEA_USAJOBS_TARGET = ApplicationTarget(BEA, 'Research Economist', custom_app_name='BEA USAJOBS', person=BEA_HM)
+
+
+def get_bea_usajobs_cv_model(model: CVModel) -> CVModel:
+    def modify_uf_description(desc: Sequence[str]) -> Sequence[str]:
+        new_first_point = """
+Conduct full economics and finance research projects, including project development, information assembly 
+and data collection from 
+multiple sources, and analysis.
+Prepare reports including statistical tables and submit papers for publication 
+in peer-reviewed journal articles to communicate economic findings
+        """.strip()
+        extra_begin_point = """
+Apply finance, econometrics, and statistics theories and methods to develop statistical models based on economic theory, 
+and apply such techniques to manipulate and analyze data
+        """.strip()
+        extra_end_point = """
+Evaluate impacts of economic policies and propose policy ideas for officials, 
+working in teams of professional economists and independently
+        """.strip()
+        second_extra_end_point = """
+Communicate economic concepts at various levels including to undergraduate students, graduate students, 
+professors, and professional economists 
+        """.strip()
+        third_extra_end_point = """
+Manage multiple simultaneous research tasks, involving economic measurement, identifying and locating data which 
+is relevant to the current task, analysis and preparation of statistical tables, and presentation of 
+findings in written research papers as well as oral presentations
+        """.strip()
+        new_desc = [
+            new_first_point,
+            extra_begin_point,
+            *desc[1:],
+            extra_end_point,
+            second_extra_end_point,
+            third_extra_end_point,
+        ]
+        return new_desc
+
+    def modify_evb_description(desc: Sequence[str]) -> Sequence[str]:
+        new_first_point = """
+Analyze and model bank commercial credit risk by forecasting credit losses, determining how much capital is required 
+to meet regulatory requirements, through rebuilding the Allowance for Loan and Lease Losses (ALLL) models, 
+ultimately saving \$5.4 million for the bank
+        """.strip()
+        new_second_point = """
+Developed credit risk metrics such as probability of default (PD) and loss given default (LGD) for 
+over 10,000 commercial
+and consumer loans by internal risk grade, delinquency status, and FFIEC code using migration analysis
+        """.strip()
+        new_third_point = """
+Evaluate operational and model risk by developing a stress testing framework
+        """.strip()
+        new_desc = [
+            new_first_point,
+            new_second_point,
+            new_third_point
+        ]
+        return new_desc
+    model.modify_job_descriptions = {
+        JobIDs.UF_GA: modify_uf_description,
+        JobIDs.EVB_PORTFOLIO_ANALYST: modify_evb_description,
+    }
+
+    app_info: Dict[str, str] = {
+        'Job Announcement Number': 'BEA-ADNEA-2021-0003',
+        'Job Title': 'Economist (Research), ZP-0110-III/IV, BEA-DHA-VFP',
+        'Grade Level(s)': 'ZP 03 - 04',
+        'Location(s)': 'Suitland, MD',
+        'Full Legal Name': 'Nicholas Andrew DeRobertis',
+        'US Citizen': 'Yes',
+        'Registered with Selective Service System': 'Yes'
+    }
+    model.application_info = app_info
+
+    model.include_hours_per_week = True
+
+    model.font_scale = 0.85
+    model.line_spacing = 0.85
+
+    sects = deepcopy(model.sections)
+    sects[4] = pl.PageBreak()
+    sects.insert(4, ResumeSection.CONTINUED)
+    model.sections = sects
+
+    return model
+
 
 JCT = Organization(
     'Joint Committee on Taxation',
